+++
title = "Multiple keywords in front-matter"
keywords = ["abc", "def", "hyphenated-keyword", "underscored_keyword", "two words", "these are four words"]
tags = ["front-matter", "keywords"]
draft = false
+++
